@@ -65,16 +65,16 @@ with other DBs.
 
 =cut
 
-use v5.16;
+use v5.14;
 
-package SQL::Steno v0.3.0;
+package SQL::Steno v0.3.1;
 
+use utf8;
 use strict;
 use warnings;
 use Time::HiRes qw(gettimeofday tv_interval);
 
-binmode STDIN, ':utf8';
-binmode STDOUT, ':utf8';
+binmode $_, ':utf8' for *STDIN, *STDOUT, *STDERR;
 
 our $dbh;
 our $perl_re = qr/(\{(?:(?>[^{}]+)|(?-1))*\})/;
@@ -129,18 +129,19 @@ sub set_render($@) {
     $render = $render{$render};
     '';				# For use as a query
 }
-our( %Queries_help, %Queries );
 
-for my $fmt ( keys %render ) {
-    $Queries_help{".$fmt"} = "   output '&.$fmt() this' or next query as \U$fmt";
-    $Queries{".$fmt"} = \&set_render;
-}
+
+
+our( %Queries_help, %Queries );
 sub Query {
     $Queries_help{$_[0]} = $_[1];
     $Queries{$_[0]} = $_[2];
     undef;
 }
-Query @$_ for
+Query ".$_", "   output '&.$_() this' or next query as \U$_", \&set_render
+    for keys %render;
+Query @$_
+    for
     ['-' => "   output next query as YAML",
       '&.yaml'],
 
@@ -176,6 +177,22 @@ Query @$_ for
      'select @a:=date(now()-interval 1 day)`@a`, @z:=date(now())-interval 1 second`@z`'];
 
 
+
+our( %Quotes_help,  %Quotes );
+sub Quote {
+    $Quotes_help{$_[0]} = $_[1];
+    $Quotes{$_[0]} = $_[2];
+    undef;
+}
+Quote @$_
+    for
+    ['a' => 'and: unquoted joined with &&',
+      '!%&&'],
+
+    ['o' => 'or: unquoted joined with ||',
+      '!%||'];
+
+
 our $weekstart = 1;		# Monday is the first day of the week as per ISO 8601.
 my $timespec_re = qr/[yqmwdhMs]?/;
 our %Join_clause;
@@ -359,9 +376,20 @@ sub find($$$\%;\@) {
 
 my %rq = ('[', ']',
 	  '{', '}');
-my $quote_re = qr(\\([-,:;./ #?\N{GREEK SMALL LETTER OMEGA}^\\\@!'"`[\]{}]*)(?:%(.+?))?);
+my $quote_re = qr(\\([^\W\d_]*)([-,:;./ #?ω^\\\@!'"`[\]{}]*)(?:%(.+?))?);
 sub quote($$@) {
-    (local $_, my $join) = splice @_, 0, 2;
+    (my $named, local $_, my $join) = splice @_, 0, 3;
+    while( $named ) {
+	my $quotes = $Quotes{$named};
+	if( !defined $quotes or "\\$quotes" !~ /^$quote_re$/o ) {
+	    warn $quotes ? "\\$named is bad '$quotes' in \%Quotes\n" : "\\$named not found in \%Quotes\n";
+	    $error = 1;
+	    return '';
+	}
+	$named = $1;
+	substr $_, 0, 0, $2;
+	$join //= $3;
+    }
     $join //= ',';
     return join $join, @_ unless defined;
     my @args = @_;
@@ -370,7 +398,7 @@ sub quote($$@) {
     $lq ||= "'";
     my $rq = $rq{$lq} || $lq;
     my( $noquote, $number, $boolean, $null, $space, $var ) =
-	(tr/!//, tr/#//, tr/?//, tr/\N{GREEK SMALL LETTER OMEGA}^//, tr/\\//, tr/@//);
+	(tr/!//, tr/#//, tr/?//, tr/ω^//, tr/\\//, tr/@//);
     my $split = tr/-// ? '-' : ''; # avoid range by putting - 1st
     $split .= tr/ // ? '\s' : '';  # space means any whitespace
     $split .= join '', /([,:;.\/])/g;
@@ -408,11 +436,11 @@ sub convert_Query($$) {
 
     my( @var, %seen, @rest );
     $res =~ s(\$$quote_re?(?:(\d+\b)|([*>_]))) {
-	if( $3 && $3 > @arg ) {
+	if( $4 && $4 > @arg ) {
 	    '';
 	} else {
-	    push @var, [$1, $2, $4 ? (undef, $4) : $3-1];
-	    undef $seen{$3-1} if $3;	# make it exist
+	    push @var, [$1, $2, $3, $5 ? (undef, $5) : $4-1];
+	    undef $seen{$4-1} if $4;	# make it exist
 	    "\cV$#var\cZ";
 	}
     }eg;
@@ -423,11 +451,11 @@ sub convert_Query($$) {
     }
     $res =~ s(\cV(\d+)\cZ) {
 	my @res = @{$var[$1]};
-	quote $res[0], $res[1],
-	    $res[3] ? ($res[3] eq '*' ? @arg :
-		       $res[3] eq '>' ? @rest :
+	quote $res[0], $res[1], $res[2],
+	    $res[4] ? ($res[4] eq '*' ? @arg :
+		       $res[4] eq '>' ? @rest :
 		       $_) :
-	    $res[2] < 0 ? $name : $arg[$res[2]];
+	    $res[3] < 0 ? $name : $arg[$res[3]];
     }eg;
     $res;
 }
@@ -457,14 +485,15 @@ sub convert_table_column {
 This function takes a short-hand query in C<$_> and transforms it to SQL.  See
 L</shell> for more run time oriented features.
 
-=head3 C<:\I<spec>(I<strings>)> E<nbsp> or E<nbsp> C<:\I<spec>%I<join>(I<strings>)>
+=head3 C<:\I<namespec>(I<strings>)> E<nbsp> or E<nbsp> C<:\I<namespec>%I<join>(I<strings>)>
 
 This is a special macro that transforms odd lists to SQL syntax.  It takes a
 list of unquoted strings and quotes each one of them in various ways.  The
 syntax is inspired by the Shell single character quote and Perl's C<\(...)>
-syntax.  The I<strings> can get split on a variety of one or even
-simultaneously various characters, which you can give in any order in the
-I<spec>:
+syntax.  The I<namespec> is a combination of an optional I<name> (set up with the
+Perl function C<Quote>), followed by an optional I<spec> that extends the named
+spec.  The I<strings> can get split on a variety of one or even simultaneously
+various characters, which you can give in any order in the I<spec>:
 
 =over
 
@@ -513,7 +542,9 @@ The boolean values C<true> and C<false> stay literal.
 
 =item C<ω> (omega) E<nbsp> or E<nbsp> C<^> (caret)
 
-The value C<null> stays literal.
+The value C<null> stays literal.  Note that C<ω> is also a word character,
+that would be part of a name at the beginning of I<namespec>.  It is only the
+C<null>-symbol following some non-word character, e.g. C<,> (comma).
 
 =item C<@> (at sign)
 
@@ -521,7 +552,7 @@ Variables C<@name> stay literal.
 
 =item C<!> (exclamation mark)
 
-Everything, presumably column names, stays literal.
+Everything, presumed valid sql syntax, stays literal.
 
 =back
 
@@ -554,7 +585,7 @@ C<:\ !%&&(a b E<nbsp>c)> gives C<a&&b&&c>.
 =head3 C<:I<macro>>
 
 These are mostly simple text-replacements stored in C<%Macros>.  Unlike
-L<C<:\>|/spec-strings-or-:-spec-join-strings> these do not take arguments.
+L<C<:\>|/namespec-strings-or-:-namespec-join-strings> these do not take arguments.
 There are also some dynamic macros.  Those starting with C<:j> (join) or
 C<:lj> (left join) may continue into a L<table spec|/tbl-or-tbl-or-tbl-alias>
 without the leading C<#>.  E.g. C<:ljtbl#t> might expand to C<left join table
@@ -628,8 +659,8 @@ alias, unless an I<alias> directly follows, in which case that is used.  It trie
 to be clever about whether the 1st C<.> needs to be preserved, i.e. following
 a table name.
 
-=head3 C<I<func>(> E<nbsp> or E<nbsp> C<I<func>\I<spec>(I<strings>)> E<nbsp>
-or E<nbsp> C<I<func>\I<spec>%I<join>(I<strings>)>
+=head3 C<I<func>(> E<nbsp> or E<nbsp> C<I<func>\I<namespec>(I<strings>)> E<nbsp>
+or E<nbsp> C<I<func>\I<namespec>%I<join>(I<strings>)>
 
 Here I<func> is a key of C<%Functions> or any
 abbreviation of known functions in C<@Functions>, which includes words
@@ -637,7 +668,7 @@ typically followed by an opening parenthesis, such as C<u(> for C<using(>.
 C<i(> becomes C<in(>, whereas C<in(> becomes C<ifnull(>.
 
 If the 2nd or 3rd form is used, the I<strings> inside of the parentheses are treated
-just like C<L<:\I<spec>(I<strings>)|/spec-strings-or-:-spec-join-strings>>,
+just like C<L<:\I<namespec>(I<strings>)|/namespec-strings-or-:-namespec-join-strings>>,
 but in this case preserving the parentheses.
 
 If the 1st argument of a function is empty and the abbrev or function is found
@@ -663,7 +694,7 @@ sub convert {
     # Handle :\...(str1, str2, str3)
     s<(?:\b(\w+)|:)$quote_re\((.+?)\)> {
 	($1 ? "$1(" : '') .
- 	quote($2, $3, $4 ) .
+ 	quote( $2, $3, $4, $5 ) .
 	($1 ? ')' : '')
     }ge;
     my @strings;		# extract strings to prevent following replacements inside.
@@ -998,13 +1029,13 @@ Here C<query> becomes the replacement string for C<&name>.  It may contain
 arguments a bit like the Shell: C<$0> (I<name>), C<$*> (all arguments), C<$1,
 $2, ..., $10, ...> (individual arguments) and C<$E<gt>> (all arguments not
 adressed individually).  They can become quoted like
-L<C<:\>|/spec-strings-or-:-spec-join-strings> as C<:\I<spec>I<arg>> or
-C<:\I<spec>%I<join>I<arg>>.  Here I<arg> is C<*>, C<E<gt>> or a number
-directly tacked on to I<spec> or I<join>.  E.g.: C<$\-"1> splits the 1st
-(semi-colon separated from the 2nd) argument itself on C<-> (minus), quotes
-the pieces with C<"> (double quote) and joins them with C<,> (comma).  Putting
-the quotes inside the argument like this, eliminates them, if no argument is
-given.
+L<C<:\>|/namespec-strings-or-:-namespec-join-strings> as
+C<$\I<namespec>I<arg>> or C<$\I<namespec>%I<join>I<arg>>.  Here I<arg> is
+C<*>, C<E<gt>> or a number directly tacked on to I<spec> or I<join>.  E.g.:
+C<$\-"1> splits the 1st (semi-colon separated from the 2nd) argument itself on
+C<-> (minus), quotes the pieces with C<"> (double quote) and joins them with
+C<,> (comma).  Putting the quotes inside the argument like this, eliminates
+them, if no argument is given.
 
 =head3 C</I<regexp>/ I<statement>> E<nbsp> or E<nbsp> C</I<regexp>/i I<statement>> E<nbsp> or E<nbsp> C<!/I<regexp>/ I<statement>> E<nbsp> or E<nbsp> C<!/I<regexp>/i I<statement>>
 
@@ -1232,7 +1263,7 @@ sub shell() {
 	goto RUN if s/^\s*=//;	# run literally
 
 	my $skip = 0;
-	if( /^\s*\?\s*(?:([?&#.:])(\w*)|(\w*)\()?/ ) { # help
+	if( /^\s*\?\s*(?:([?&#.:\\])(\w*)|(\w*)\()?/ ) { # help
 	    if( $1 && $1 eq '?' ) {
 		s/^\s*\?\s*\?//;
 		$skip = 1;
@@ -1350,15 +1381,16 @@ Query has the form {select|update|insert|delete}{fieldlist};tablelist{;clause} o
 fieldlist defaults to '*', also if Query starts with '#'.
 ';' is alternately replaced by 'from' and 'where'.
 
-Abbreviations, more help with ?&{abbrev}, ?:{abbrev}, ?#{abbrev}, ?.{abbrev}, ?{abbrev}(
+Abbreviations, more help with ?&{abbrev}, ?:{abbrev}, ?\{abbrev}, ?#{abbrev}, ?.{abbrev}, ?{abbrev}(
 &{Perl code}...		# only at bol, if it returns undef then skip, else prepend to ...
 &query $1;$2;...	# only at bol
 &query($1;$2;...)...	# only at bol, only replace upto )
+:macro
+:\quote(arg,...)	# split, quote & join (?\ alone needs trailing space, because \ at end continues)
+:{Perl code}		# dynamic macro
 #table #table#t
 .column	.column.c	# for any table recognized in statement
 function(
-:macro
-:{Perl code}		# dynamic macro
 
 Characters \t\n\r get masked in output, \r\n as \R.
 Date or time 0000-00-00 -> 0000-  1970-01-01 -> 1970-  00:00:00 -> 00:  23:59:59 -> 24:
@@ -1367,7 +1399,7 @@ HELP
 	@keys_Table_Columns = keys %Table_Columns unless @keys_Table_Columns;
 	helphash $_[1], '#', '', %Tables, @keys_Table_Columns;
     } elsif( $_[0] eq '.' ) {
-	helphashalt %Columns, 'ptr' unless $_[1];
+	helphashalt %Columns, 'ptr' unless $_[1]; # \todo WIN@
 	$error or print "$_\n" if
 	    $_[1] and $_ = find $_[1], '.', '', %Columns; # \todo, @column;
     } elsif( $_[0] eq '&' ) {
@@ -1380,6 +1412,15 @@ HELP
 	$?arg?arg-replacement?no-arg-replacement? 1st if $arg has a value
 HELP
 	helphash $_[1], '&', '', %Queries_help;
+    } elsif( $_[0] eq '\\' ) {
+	print <<\HELP unless $_[1];
+:\namespec(arg,...) or func\namespec(arg,...) quotes args for you.
+&{ Quote name => 'doc', 'namespec' }   define quote \name on the fly
+	namespec may another name and/or any splitter chars (-,:;./ ),
+	preventer chars (#?ω^\@!), quoting chars ('"`[]{}) and/or
+	a string to join the results with after a %.
+HELP
+	helphash $_[1], '\\', '', %Quotes_help;
     } else {
 	print <<\HELP unless $_[1];
 :\(...)	 split arguments and quote in many ways
